@@ -12,5 +12,9 @@
 # implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
+module OpenID
+  VERSION = "2.1.2"
+end
+
 require "openid/consumer"
 require 'openid/server'
